// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef STEREO_MSGS__MSG__DISPARITY_IMAGE_HPP_
#define STEREO_MSGS__MSG__DISPARITY_IMAGE_HPP_

#include "stereo_msgs/msg/detail/disparity_image__struct.hpp"
#include "stereo_msgs/msg/detail/disparity_image__builder.hpp"
#include "stereo_msgs/msg/detail/disparity_image__traits.hpp"
#include "stereo_msgs/msg/detail/disparity_image__type_support.hpp"

#endif  // STEREO_MSGS__MSG__DISPARITY_IMAGE_HPP_
